@@ -7,6 +7,7 @@ use Nabaztag ;
 
 my $mac = shift ;
 my $tok = shift ;
+my $key = shift ;
 
 my $left = shift || 0 ;
 my $right = shift || 0 ;
@@ -16,6 +17,8 @@ my $mess = shift ;
 my $nab = Nabaztag->new();
 $nab->mac($mac);
 $nab->token($tok);
+$nab->key($key);
+
 $nab->leftEarPos($left);
 $nab->rightEarPos($right);
 
